import argparse
import matplotlib.pyplot as plt

def get_args():
    parser = argparse.ArgumentParser(description='Plot mouse movement ' +
            'coordinates extracted from Synergy network traffic.')
    parser.add_argument('hexStream', help='File containing Synergy ' +
            'traffic in HEX format')
    args = parser.parse_args()
    return args

#Search hex stream for mouse movement magic numbers
def find_coords(filename):
    '''
    Add coordinates found in hex stream to lists.
    '''
    #Magic numbers
    movementNumber = '44 4d 4d 56'
    clickNumber = '44 4d 44 4e  01'
    releaseNumber = '44 4d 55 50  01'
    #Lists of coordinates
    xCoords = []
    yCoords = []
    clickX = []
    clickY = []
    releaseX = []
    releaseY = []
    hexFile = open(filename)
    for line in hexFile:
        if movementNumber in line:
            #Get line after hex magic number
            coordLine = line.split(movementNumber,1)[1]
            getMovementCoords(coordLine, xCoords, yCoords)
        if clickNumber in line:
            clickX.append(xCoords[-1])
            clickY.append(yCoords[-1])
        if releaseNumber in line:
            releaseX.append(xCoords[-1])
            releaseY.append(yCoords[-1])
    
    #Return all lists of coordinates
    return(xCoords, yCoords, clickX, clickY, releaseX, releaseY)

def getMovementCoords(line, xCoords, yCoords):
    '''
    Add numbers after magic number (these are the x- and y-coordinates)
    to lists.
    '''
    xHex = str(line.split()[0] + line.split()[1])
    xCoords.append(int(xHex, 16))
    yHex = str(line.split()[2] + line.split()[3])
    yCoords.append(int(yHex, 16))

def plot(xCoords, yCoords, style=None):
    '''
    Plot coordinate points.
    '''
    if style is not None:
        plt.plot(xCoords, yCoords, style)
    else:
        plt.plot(xCoords, yCoords)
    plt.axis([0, 1500, 0, 1000])
    plt.savefig('mouse-movements.png', bbox_inches='tight')

def main():
    args = get_args()
    moveX, moveY, clickX, clickY, releaseX, releaseY = find_coords(args.hexStream)
    plot(moveX, moveY)
    plot(clickX, clickY, 'go')
    plot(releaseX, releaseY, 'ro')

if __name__ == '__main__':
    main()
